@@ -3,14 +3,16 @@
 #' Compute the Cholesky factorization of a non-real symmetric positive-definite square matrix.
 #'
 #' @param G (numeric - matrix) an object to apply this method, it could be non positive-definite matrices.
+#' @param tolerance (\code{double}) Tolerance level, by default is 1e-10.
 #'
 #' @export
 #'
-cholesky <- function(G) {
+cholesky <- function(G, tolerance = 1e-10) {
   EigenA <- eigen(G)
   d_A    <- EigenA$values
   V_A    <- EigenA$vectors
-  pos_A1 <- which(d_A > 1e-10)
+  d_A[which(d_A < tolerance)] <- tolerance*100L
+  pos_A1 <- which(d_A > tolerance)
   if (identical(pos_A1, integer(0))) {
     pos_A <- 1L
   } else {
@@ -20,7 +22,7 @@ cholesky <- function(G) {
   V_A_Star <- V_A[, pos_A]
 
   if (length(pos_A) == 1L) {
-    d_A_Star <- 1 / d_A_Star
+    d_A_Star <- 1L / d_A_Star
     LG <- d_A_Star * sqrt(V_A_Star)
   } else {
     d_A_Star <- diag(d_A_Star)
